← Back to team overview

ubuntu-touch-coreapps-reviewers team mailing list archive

[Merge] lp:~carlos-mazieri/ubuntu-filemanager-app/new-protocols-support-03 into lp:ubuntu-filemanager-app

 

Carlos Jose Mazieri has proposed merging lp:~carlos-mazieri/ubuntu-filemanager-app/new-protocols-support-03 into lp:ubuntu-filemanager-app with lp:~carlos-mazieri/ubuntu-filemanager-app/new-protocols-support-02 as a prerequisite.

Commit message:
ust fixed a typo in some files 'indexOfColonAndSlashe' should not have the final 'e' as it refers to ':/'

Requested reviews:
  Ubuntu File Manager Developers (ubuntu-filemanager-dev)

For more details, see:
https://code.launchpad.net/~carlos-mazieri/ubuntu-filemanager-app/new-protocols-support-03/+merge/280389

ust fixed a typo in some files 'indexOfColonAndSlashe' should not have the final 'e' as it refers to ':/'
-- 
Your team Ubuntu File Manager Developers is requested to review the proposed merge of lp:~carlos-mazieri/ubuntu-filemanager-app/new-protocols-support-03 into lp:ubuntu-filemanager-app.
=== modified file 'src/plugin/folderlistmodel/disk/disklocation.cpp'
--- src/plugin/folderlistmodel/disk/disklocation.cpp	2015-12-12 15:45:39 +0000
+++ src/plugin/folderlistmodel/disk/disklocation.cpp	2015-12-12 15:45:39 +0000
@@ -178,12 +178,12 @@
 }
 
 
-QString DiskLocation::urlBelongsToLocation(const QString &urlPath, int indexOfColonAndSlashe)
+QString DiskLocation::urlBelongsToLocation(const QString &urlPath, int indexOfColonAndSlash)
 {
     QString ret;
     if (urlPath.startsWith(LocationUrl::DiskRootURL.midRef(0,5)))
     {
-        ret  = QDir::rootPath() + DirItemInfo::removeExtraSlashes(urlPath, indexOfColonAndSlashe+1);
+        ret  = QDir::rootPath() + DirItemInfo::removeExtraSlashes(urlPath, indexOfColonAndSlash+1);
     }
     return ret;
 }

=== modified file 'src/plugin/folderlistmodel/disk/disklocation.h'
--- src/plugin/folderlistmodel/disk/disklocation.h	2015-12-12 15:45:39 +0000
+++ src/plugin/folderlistmodel/disk/disklocation.h	2015-12-12 15:45:39 +0000
@@ -70,7 +70,7 @@
     virtual LocationItemFile   * newFile(const QString & path);
     virtual LocationItemDir    * newDir(const QString & dir = QLatin1String(0));
     virtual bool        isThereDiskSpace(const QString& pathname, qint64 requiredSize);
-    virtual QString     urlBelongsToLocation(const QString& urlPath, int indexOfColonAndSlashe);
+    virtual QString     urlBelongsToLocation(const QString& urlPath, int indexOfColonAndSlash);
 
 protected:
     void    addExternalFsWorkerRequest(ExternalFileSystemChangesWorker *);

=== modified file 'src/plugin/folderlistmodel/location.h'
--- src/plugin/folderlistmodel/smb/smblocation.cpp	2015-12-12 15:45:39 +0000
+++ src/plugin/folderlistmodel/smb/smblocation.cpp	2015-12-12 15:45:39 +0000
@@ -95,14 +95,14 @@
 }
 
 
-QString SmbLocation::urlBelongsToLocation(const QString &urlPath, int indexOfColonAndSlashe)
+QString SmbLocation::urlBelongsToLocation(const QString &urlPath, int indexOfColonAndSlash)
 {
     QString ret;
     if ( urlPath.startsWith(LocationUrl::SmbURL.midRef(0,4)) ||
          urlPath.startsWith(LocationUrl::CifsURL.midRef(0,5))
        )
     {
-        ret  = LocationUrl::SmbURL + DirItemInfo::removeExtraSlashes(urlPath, indexOfColonAndSlashe+1);
+        ret  = LocationUrl::SmbURL + DirItemInfo::removeExtraSlashes(urlPath, indexOfColonAndSlash+1);
     }
     return ret;
 }

=== modified file 'src/plugin/folderlistmodel/smb/smblocation.h'
--- src/plugin/folderlistmodel/smb/smblocation.h	2015-12-12 15:45:39 +0000
+++ src/plugin/folderlistmodel/smb/smblocation.h	2015-12-12 15:45:39 +0000
@@ -45,8 +45,8 @@
                                                       LocationItemDirIterator::LoadMode loadmode = LocationItemDirIterator::LoadOnConstructor);
     virtual LocationItemFile   * newFile(const QString & path);   
     virtual LocationItemDir    * newDir(const QString & dir = QLatin1String(0));
-     virtual bool       isThereDiskSpace(const QString& pathname, qint64 requiredSize);
-    virtual QString     urlBelongsToLocation(const QString& urlPath, int indexOfColonAndSlashe);
+    virtual bool        isThereDiskSpace(const QString& pathname, qint64 requiredSize);
+    virtual QString     urlBelongsToLocation(const QString& urlPath, int indexOfColonAndSlash);
     virtual QString     currentAuthenticationUser();
     virtual QString     currentAuthenticationPassword();
 


Follow ups
--- src/plugin/folderlistmodel/location.h	2015-12-12 15:45:39 +0000
+++ src/plugin/folderlistmodel/location.h	2015-12-12 15:45:39 +0000
@@ -153,7 +153,7 @@
       *  If the URL or Path in \a urlPath is valid and belongs to its location
       *
       * \param urlPath                  The input URL that is going to be parsed
       * \param indexOfColonAndSlashe    The index of ":/"
       * \return                         The good URL (parsed with extra slashes removed)
       *                                 or an empty string if \a urlPath does not belong to its location
       *
@@ -166,7 +166,7 @@
       *    The return will be: an empty string meaning that this URL is not related to Samba
       *\endcode
       */
-     virtual QString         urlBelongsToLocation(const QString& urlPath, int indexOfColonAndSlashe) = 0;
+     virtual QString         urlBelongsToLocation(const QString& urlPath, int indexOfColonAndSlash) = 0;
 
 public:
     /*!
@@ -153,7 +153,7 @@
       *
       * \param urlPath                  The input URL that is going to be parsed
-      * \param indexOfColonAndSlashe    The index of ":/"
+      * \param indexOfColonAndSlash     The index of ":/"
       * \return                         The good URL (parsed with extra slashes removed)
       *                                 or an empty string if \a urlPath does not belong to its location

=== modified file 'src/plugin/folderlistmodel/smb/smblocation.cpp'